QWED Test Report - 2025-12-01

# 🛡️ QWED Comprehensive Test Audit

Generated: 2025-12-01 05:10:03

NEEDS IMPROVEMENT
Total Tests
13
Passed
9
Failed
4
Pass Rate
69.2%
Duration
1.7s

## 📊 Results by Priority

Priority | Total | Passed | Failed | Pass Rate
--- | --- | --- | --- | ---
CRITICAL | 10 | 7 | 3 | 70.0%
HIGH | 3 | 2 | 1 | 66.7%
MEDIUM | 0 | 0 | 0 | 0.0%

## 🔧 Results by Engine

Engine | Total | Passed | Failed | Pass Rate
--- | --- | --- | --- | ---
CODE | 13 | 9 | 4 | 69.2%

## ❌ Failed Tests (4)

### Detect getattr() with user input

Engine: code Priority: CRITICAL ID: CODE_AST_002

### Detect MD5 for password hashing

Engine: code Priority: CRITICAL ID: CODE_CRYPTO_001

### Detect hardcoded encryption keys

Engine: code Priority: CRITICAL ID: CODE_CRYPTO_002

### Detect SHA-256 without salt

Engine: code Priority: HIGH ID: CODE_CRYPTO_003